@@ -30,6 +30,9 @@ class Base:
     def to_pandas(self, **kwargs):
         self._not_implemented()
 
+    def to_tfdataset(self, **kwargs):
+        self._not_implemented()
+
     def to_metview(self, **kwargs):
         self._not_implemented()
 
@@ -40,6 +43,13 @@ class Base:
     def field_metadata(self):
         self._not_implemented()
 
+    # I/O
+    def save(self, path):
+        self._not_implemented()
+
+    def write(self, f):
+        self._not_implemented()
+
     # Used by normalisers
     def to_datetime(self):
         self._not_implemented()
@@ -57,4 +67,8 @@ class Base:
         func = inspect.stack()[1][3]
         module = self.__class__.__module__
         name = self.__class__.__name__
-        raise NotImplementedError(f"{module}.{name}.{func}()")
+
+        extra = ""
+        if hasattr(self, "path"):
+            extra = self.path
+        raise NotImplementedError(f"{module}.{name}.{func}({extra})")
