@@ -17,7 +17,8 @@ from climetlab.core import Base
 # from climetlab.decorators import dict_args
 from climetlab.utils.bbox import BoundingBox
 
-from . import MultiReaders, Reader
+from . import Reader
+from .gridded import GriddedMultiReaders
 
 LOG = logging.getLogger(__name__)
 
@@ -217,12 +218,14 @@ class GRIBFilter:
         return GRIBIterator(self.path)
 
 
-class MultiGribReaders(MultiReaders):
+class MultiGribReaders(GriddedMultiReaders):
     engine = "cfgrib"
     backend_kwargs = {"squeeze": False}
 
 
 class GRIBReader(Reader):
+    appendable = True  # GRIB messages can be added to the same file
+
     def __init__(self, source, path):
         super().__init__(source, path)
         self._fields = None
@@ -259,6 +262,6 @@ class GRIBReader(Reader):
         return MultiGribReaders(readers)
 
 
-def reader(source, path, magic):
+def reader(source, path, magic, deeper_check):
     if magic[:4] == b"GRIB":
         return GRIBReader(source, path)
