@@ -19,7 +19,8 @@ import xarray as xr
 from climetlab.core import Base
 from climetlab.utils.bbox import BoundingBox
 
-from . import MultiReaders, Reader
+from . import Reader
+from .gridded import GriddedMultiReaders
 
 
 def as_datetime(self, time):
@@ -187,7 +188,7 @@ class NetCDFField(Base):
         )
 
 
-class MultiNetcdfReaders(MultiReaders):
+class MultiNetcdfReaders(GriddedMultiReaders):
     engine = "netcdf4"
 
 
@@ -223,6 +224,8 @@ class NetCDFReader(Reader):
 
     def _get_fields(self, ds):  # noqa C901
         # Select only geographical variables
+        has_lat = False
+        has_lon = False
 
         fields = []
 
@@ -320,6 +323,6 @@ class NetCDFReader(Reader):
         return MultiNetcdfReaders(readers)
 
 
-def reader(source, path, magic):
+def reader(source, path, magic, deeper_check):
     if magic[:4] in (b"\x89HDF", b"CDF\x01", b"CDF\x02"):
         return NetCDFReader(source, path)
