@@ -11,7 +11,8 @@ import cdsapi
 
 from climetlab.normalize import normalize_args
 
-from .base import APIKeyPrompt, FileSource
+from .file import FileSource
+from .prompt import APIKeyPrompt
 
 APIRC = "key: {key}\nurl: https://cds.climate.copernicus.eu/api/v2"
 
@@ -79,13 +80,27 @@ class CDSRetriever(FileSource):
     def request(self, **kwargs):
         return kwargs
 
-    def read_csv_options(self):
-        return dict(
+    def to_pandas(self, **kwargs):
+        pandas_read_csv_kwargs = dict(
             comment="#",
             parse_dates=["report_timestamp"],
             skip_blank_lines=True,
             compression="zip",
         )
 
+        pandas_read_csv_kwargs.update(kwargs.get("pandas_read_csv_kwargs", {}))
+
+        odc_read_odb_kwargs = dict(
+            # TODO
+        )
+
+        odc_read_odb_kwargs.update(kwargs.get("odc_read_odb_kwargs", {}))
+
+        return super().to_pandas(
+            pandas_read_csv_kwargs=pandas_read_csv_kwargs,
+            odc_read_odb_kwargs=odc_read_odb_kwargs,
+            **kwargs,
+        )
+
 
 source = CDSRetriever
